==> petsc-3.24.1-1-x86_64.pkg.tar.zst: opt/petsc/linux-c-opt/include/petscmachineinfo.h <==
static const char *petscmachineinfo = "\n"
"-----------------------------------------\n"
"Libraries compiled on 2025-11-02 20:27:42 on reproducible\n"
"Machine characteristics: Linux-6.11.0-1018-azure-x86_64-with-glibc2.42\n"
"Using PETSc directory: /opt/petsc/linux-c-opt\n"
"Using PETSc arch: \n"
"-----------------------------------------\n";
static const char *petsccompilerinfo = "\n"
"Using C compiler: /usr/bin/mpicc -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -flto=auto -fPIC \n"
"Using Fortran compiler: /usr/bin/mpif90 -march=x86-64 -mtune=generic -O2 -pipe -fno-plt         -Wp,-D_FORTIFY_SOURCE=3 -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -fPIC   \n"
"-----------------------------------------\n";
static const char *petsccompilerflagsinfo = "\n"
"Using include paths: -I/opt/petsc/linux-c-opt/include -I/usr/include/hypre -I/usr/include/suitesparse -I/usr/include -I/usr/include/superlu_dist -I/usr/include/superlu\n"
"-----------------------------------------\n";
static const char *petsclinkerinfo = "\n"
"Using C linker: /usr/bin/mpicc\n"
"Using Fortran linker: /usr/bin/mpif90\n"
"Using libraries: -Wl,-rpath,/opt/petsc/linux-c-opt/lib -L/opt/petsc/linux-c-opt/lib -lpetsc -Wl,-rpath,/usr/lib/gcc/x86_64-pc-linux-gnu/15.2.1 -L/usr/lib/gcc/x86_64-pc-linux-gnu/15.2.1 /usr/lib/libHYPRE.so -lspqr -lumfpack -lklu -lcholmod -lamd -lfftw3_mpi -lfftw3 -ldmumps -lmumps_common -lpord -lpthread -lscalapack -lsuperlu_dist -lpastix -lsuperlu -llapack -lblas -lzfp -lesmumps -lptscotch -lptscotcherr -lscotch -lscotcherr -lnetcdf -lhdf5_hl_fortran -lhdf5_fortran -lhdf5_hl_f90cstub -lhdf5_f90cstub -lhdf5_hl -lhdf5 -lparmetis -lmetis -lgsl -lgslcblas -lm -lz -ljpeg -lyaml -lhwloc -lmpi_usempif08 -lmpi_usempi_ignore_tkr -lmpi_mpifh -lmpi -lgfortran -lm -lgfortran -lm -lgcc_s -lquadmath\n"
"-----------------------------------------\n";

==> petsc-3.24.2-1-x86_64.pkg.tar.zst: opt/petsc/linux-c-opt/include/petscmachineinfo.h <==
static const char *petscmachineinfo = "\n"
"-----------------------------------------\n"
"Libraries compiled on 2025-12-17 13:14:33 on reproducible\n"
"Machine characteristics: Linux-6.11.0-1018-azure-x86_64-with-glibc2.42\n"
"Using PETSc directory: /opt/petsc/linux-c-opt\n"
"Using PETSc arch: \n"
"-----------------------------------------\n";
static const char *petsccompilerinfo = "\n"
"Using C compiler: /usr/bin/mpicc -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -flto=auto -fPIC \n"
"Using Fortran compiler: /usr/bin/mpif90 -march=x86-64 -mtune=generic -O2 -pipe -fno-plt         -Wp,-D_FORTIFY_SOURCE=3 -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -fPIC   \n"
"-----------------------------------------\n";
static const char *petsccompilerflagsinfo = "\n"
"Using include paths: -I/opt/petsc/linux-c-opt/include -I/usr/include/hypre -I/usr/include/suitesparse -I/usr/include -I/usr/include/superlu_dist -I/usr/include/superlu\n"
"-----------------------------------------\n";
static const char *petsclinkerinfo = "\n"
"Using C linker: /usr/bin/mpicc\n"
"Using Fortran linker: /usr/bin/mpif90\n"
"Using libraries: -Wl,-rpath,/opt/petsc/linux-c-opt/lib -L/opt/petsc/linux-c-opt/lib -lpetsc -Wl,-rpath,/usr/lib/gcc/x86_64-pc-linux-gnu/15.2.1 -L/usr/lib/gcc/x86_64-pc-linux-gnu/15.2.1 /usr/lib/libHYPRE.so -lspqr -lumfpack -lklu -lcholmod -lamd -lfftw3_mpi -lfftw3 -ldmumps -lmumps_common -lpord -lpthread -lscalapack -lsuperlu_dist -lpastix -lsuperlu -llapack -lblas -lzfp -lesmumps -lptscotch -lptscotcherr -lscotch -lscotcherr -lhdf5_hl_fortran -lhdf5_fortran -lhdf5_hl_f90cstub -lhdf5_f90cstub -lhdf5_hl -lhdf5 -lparmetis -lmetis -lgsl -lgslcblas -lm -ljpeg -lyaml -lhwloc -lmpi_usempif08 -lmpi_usempi_ignore_tkr -lmpi_mpifh -lmpi -lgfortran -lm -lgfortran -lm -lgcc_s -lquadmath\n"
"-----------------------------------------\n";
